@@ -17,7 +17,7 @@ public:
 	virtual bool isReady(const basic_socket_stream*) = 0;
 };
 
-class Poll : public SigC::Signal1<void,PollData&>
+class Poll
 {
 public:
 	Poll() {}
@@ -36,8 +36,9 @@ public:
 	static Poll& instance();
 	static void setInstance(Poll*);
 
-	static void newTimeout() {new_timeout_ = true;}
+	static void newTimedEvent() {new_timeout_ = true;}
 
+    sigc::signal<void, PollData&> Ready;
 private:
 	Poll(const Poll&);
 	static Poll *_inst;
